@@ -29,8 +29,10 @@ class Pinyin(object):
         >>> p.get_pinyin(u"上海")
         'shang-hai'
         >>> # show tone marks
-        >>> p.get_pinyin(u"上海", show_tone_marks=True)
+        >>> p.get_pinyin(u"上海", tone_marks='marks')
         'shàng-hǎi'
+        >>> p.get_pinyin(u"上海", tone_marks='numbers')
+        >>> 'shang4-hai3'
         >>> # remove splitter
         >>> p.get_pinyin(u"上海", '')
         'shanghai'
@@ -55,61 +57,71 @@ class Pinyin(object):
 
     def __init__(self, data_path=data_path):
         self.dict = {}
-        for line in open(data_path):
-            k, v = line.split('\t')
-            self.dict[k] = v
+        with open(data_path) as f:
+            for line in f:
+                k, v = line.split('\t')
+                self.dict[k] = v
 
-    def decode_pinyin(self, s):
+    @staticmethod
+    def decode_pinyin(s):
         s = s.lower()
         r = ""
         t = ""
         for c in s:
-            if c >= 'a' and c <= 'z':
+            if "a" <= c <= 'z':
                 t += c
             elif c == ':':
                 assert t[-1] == 'u'
                 t = t[:-1] + "\u00fc"
             else:
-                if c >= '0' and c <= '5':
+                if '0' <= c <= '5':
                     tone = int(c) % 5
                     if tone != 0:
                         m = re.search("[aoeiuv\u00fc]+", t)
                         if m is None:
+                            # pass when no vowels find yet
                             t += c
                         elif len(m.group(0)) == 1:
-
-                            t = t[:m.start(0)]\
-                                + PinyinToneMark[tone][
-                                    PinyinToneMark[0].index(m.group(0))]\
+                            # if just find one vowels, put the mark on it
+                            t = t[:m.start(0)] \
+                                + PinyinToneMark[tone][PinyinToneMark[0].index(m.group(0))] \
                                 + t[m.end(0):]
                         else:
-                            if 'a' in t:
-                                t = t.replace("a", PinyinToneMark[tone][0])
-                            elif 'o' in t:
-                                t = t.replace("o", PinyinToneMark[tone][1])
-                            elif 'e' in t:
-                                t = t.replace("e", PinyinToneMark[tone][2])
-                            elif t.endswith("ui"):
-                                t = t.replace("i", PinyinToneMark[tone][3])
-                            elif t.endswith("iu"):
-                                t = t.replace("u", PinyinToneMark[tone][4])
-                            else:
-                                t += "!"
+                            # mark on vowels which search with "a, o, e" one by one
+                            # when "i" and "u" stand together, make the vowels behind
+                            for num, vowels in enumerate(("a", "o", "e", "ui", "iu")):
+                                if vowels in t:
+                                    t = t.replace(vowels[-1], PinyinToneMark[tone][num])
+                                    break
                 r += t
                 t = ""
         r += t
         return r
 
-    def get_pinyin(self, chars=u'你好', splitter=u'-', show_tone_marks=False):
+    @staticmethod
+    def convert_pinyin(word, convert):
+        if convert == 'capitalize':
+            return word.capitalize()
+        if convert == 'lower':
+            return word.lower()
+        if convert == 'upper':
+            return word.upper()
+
+    def get_pinyin(self, chars=u'你好', splitter=u'-',
+                   tone_marks=None, convert='lower'):
         result = []
         flag = 1
         for char in chars:
             key = "%X" % ord(char)
             try:
-                result.append(self.decode_pinyin(
-                    self.dict[key].split()[0].strip().lower())
-                    if show_tone_marks
-                    else self.dict[key].split()[0].strip()[:-1].lower())
+                if tone_marks == 'marks':
+                    word = self.decode_pinyin(self.dict[key].split()[0].strip())
+                elif tone_marks == 'numbers':
+                    word = self.dict[key].split()[0].strip()
+                else:
+                    word = self.dict[key].split()[0].strip()[:-1]
+                word = self.convert_pinyin(word, convert)
+                result.append(word)
                 flag = 1
             except KeyError:
                 if flag:
@@ -117,7 +129,6 @@ class Pinyin(object):
                 else:
                     result[-1] += char
                 flag = 0
-
         return splitter.join(result)
 
     def get_initial(self, char=u'你'):
